@@ -45,12 +45,8 @@ def bw_generate_new_biosphere_data_water(bio_act_list, new_bio_name):
 
 def bw_add_lcia_method_aware():
     flows_list = []
-    from importlib.resources import files
-    import ppplca.data.regionalization_setup as data_pkg
-
-    path = files(data_pkg).joinpath("cf_aware_processed.csv")
-    with path.open(encoding="latin1") as f:
-        df = pd.read_csv(f, sep=",")
+    with resources.open_text("ppplca.data.regionalization_setup","cf_aware_processed.csv", encoding="latin1") as f:
+        df = pd.read_csv(f, encoding="latin1", sep=";")
     df = df.map(lambda x: x.replace('__', ',') if isinstance(x, str) else x)
     df = df.drop("Column1",axis=1)
     df['Location'] = df['Location'].fillna('NA')
@@ -58,7 +54,6 @@ def bw_add_lcia_method_aware():
     new_bio_db = bd.Database('biosphere water regionalized')
     for flow in new_bio_db:
         loc = flow.get('location')
-        print(loc)
         if 'irrigation' in flow.get('name'):
             cf = df.loc[df.Location == loc, 'Agg_CF_irri'].iloc[0]
         else:
@@ -389,7 +384,7 @@ def regionalize_db(db_name):
 
         # flag_db = ei.metadata.get("regionalized", False)
         # if not flag_db:
-        print('start regionalizing water and land flows')
+        print('start regionalizing water, land, and pm flows')
         water_use_list = [act for act in bio if "Water" in act['name']
                           and 'natural resource' in act['categories']
                           and 'air' not in act['name']
