@@ -13,11 +13,11 @@ def setup():
     setupdatabasecommand = SetupDatabaseCommand()
     setupdatabasecommand.handle()
 
-def run():
-    answer = input("Have you updated the Processing_data.xlsx and value_chains_test.xlsx files? [Y/n]: ")
+def run(file="value_chains_test.xlsx", sheet_name = None):
+    answer = input(f"Have you updated the Processing_data.xlsx and {file} files? [Y/n]: ")
     if answer.lower() != "y":
         print("Please update the filese before running the setup.")
         return
     from ppplca.Commands.RunCommand import RunCommand
-    rundatabasecommand = RunCommand()
+    rundatabasecommand = RunCommand(file, sheet_name)
     rundatabasecommand.handle()
\ No newline at end of file
